@@ -15,7 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef _ANJUTA_PLUGIN_HANDLE_H_
@@ -54,6 +54,7 @@ const char* anjuta_plugin_handle_get_id (AnjutaPluginHandle *plugin_handle);
 const char* anjuta_plugin_handle_get_name (AnjutaPluginHandle *plugin_handle);
 const char* anjuta_plugin_handle_get_about (AnjutaPluginHandle *plugin_handle);
 const char* anjuta_plugin_handle_get_icon_path (AnjutaPluginHandle *plugin_handle);
+const char* anjuta_plugin_handle_get_path (AnjutaPluginHandle *plugin_handle);
 gboolean anjuta_plugin_handle_get_user_activatable (AnjutaPluginHandle *plugin_handle);
 gboolean anjuta_plugin_handle_get_resident (AnjutaPluginHandle *plugin_handle);
 const char* anjuta_plugin_handle_get_language (AnjutaPluginHandle *plugin_handle);
