@@ -107,7 +107,8 @@ typedef enum
 	ANJUTA_PROJECT_SOURCE = 4 << 24,
 	ANJUTA_PROJECT_MODULE = 5 << 24,
 	ANJUTA_PROJECT_PACKAGE = 6 << 24,
-	ANJUTA_PROJECT_VARIABLE = 7 << 24
+	ANJUTA_PROJECT_VARIABLE = 7 << 24,
+	ANJUTA_PROJECT_OBJECT = 8 << 24,
 } AnjutaProjectNodeType;
 
 typedef enum
@@ -174,6 +175,7 @@ AnjutaProjectNode *anjuta_project_node_last_child (AnjutaProjectNode *node);
 AnjutaProjectNode *anjuta_project_node_next_sibling (AnjutaProjectNode *node);
 AnjutaProjectNode *anjuta_project_node_prev_sibling (AnjutaProjectNode *node);
 AnjutaProjectNode *anjuta_project_node_nth_child (AnjutaProjectNode *node, guint n);
+AnjutaProjectNode *anjuta_project_node_parent_type (AnjutaProjectNode *node, AnjutaProjectNodeType type);
 
 void anjuta_project_node_foreach (AnjutaProjectNode *node, GTraverseType order, AnjutaProjectNodeForeachFunc func, gpointer data);
 void anjuta_project_node_children_foreach (AnjutaProjectNode *node, AnjutaProjectNodeForeachFunc func, gpointer data);
@@ -198,6 +200,7 @@ GFile *anjuta_project_node_get_file (const AnjutaProjectNode *node);
 GList *anjuta_project_node_get_native_properties (AnjutaProjectNode *node);
 GList *anjuta_project_node_get_custom_properties (AnjutaProjectNode *node);
 AnjutaProjectProperty *anjuta_project_node_get_property (AnjutaProjectNode *node, AnjutaProjectProperty *property);
+AnjutaProjectProperty *anjuta_project_node_get_map_property (AnjutaProjectNode *node, AnjutaProjectProperty *property, const gchar *name);
 
 gboolean anjuta_project_node_set_state (AnjutaProjectNode *node, AnjutaProjectNodeState state);
 gboolean anjuta_project_node_clear_state (AnjutaProjectNode *node, AnjutaProjectNodeState state);
