@@ -155,6 +155,19 @@ sdb_system_finalize (GObject *object)
 	
 	sdbs = SYMBOL_DB_SYSTEM (object);
 	priv = sdbs->priv;
+	
+	/* disconnect all signals */
+	g_signal_handlers_disconnect_by_func (G_OBJECT (priv->sdbe_globals),
+									  on_engine_package_single_file_scan_end,
+									  sdbs);
+	g_signal_handlers_disconnect_matched (G_OBJECT (priv->sdbe_globals),
+									  G_SIGNAL_MATCH_FUNC,
+									  0,
+									  0,
+									  NULL,
+									  on_engine_package_scan_end,
+									  NULL);
+	
 	if (priv->single_package_scan_launcher) 
 	{
 		anjuta_launcher_reset (priv->single_package_scan_launcher);
@@ -167,13 +180,10 @@ sdb_system_finalize (GObject *object)
 	g_queue_free (priv->sscan_queue);
 	priv->sscan_queue = NULL;	
 	
-	/* FIXME: missing engine queue */
-	/* disconnect signals */
-	g_signal_handlers_disconnect_by_func (G_OBJECT (priv->sdbe_globals),
-									  on_engine_package_single_file_scan_end,
-									  sdbs);
-	
-	
+	/* free engine queue */
+	g_queue_foreach (priv->engine_queue, (GFunc)destroy_engine_scan_data, NULL);
+	g_queue_free (priv->engine_queue);
+	priv->engine_queue = NULL;	
 	
 	G_OBJECT_CLASS (sdb_system_parent_class)->finalize (object);
 }
@@ -282,7 +292,8 @@ symbol_db_system_new (SymbolDBPlugin *sdb_plugin,
  */
 gboolean
 symbol_db_system_is_package_parsed (SymbolDBSystem *sdbs, 
-								   const gchar * package_name)
+								   	const gchar * package_name, 
+    								const gchar * package_version)
 {
 	SymbolDBSystemPriv *priv;
 		
@@ -292,7 +303,7 @@ symbol_db_system_is_package_parsed (SymbolDBSystem *sdbs,
 	priv = sdbs->priv;
 	
 	return symbol_db_engine_project_exists (priv->sdbe_globals, 
-											package_name);
+											package_name, package_version);
 }
 
 static void
@@ -499,7 +510,7 @@ sdb_system_do_engine_scan (SymbolDBSystem *sdbs, EngineScanData *es_data)
 								 languages_array);
 		
 		symbol_db_engine_add_new_project (priv->sdbe_globals, NULL,
-								  		es_data->package_name);
+								  		es_data->package_name, "1.0");
 	}
 	else 
 	{
@@ -513,9 +524,10 @@ sdb_system_do_engine_scan (SymbolDBSystem *sdbs, EngineScanData *es_data)
 	 * infact to have more references of the same files in different
 	 * packages
 	 */
-	proc_id = symbol_db_engine_add_new_files_full (priv->sdbe_globals,
+	proc_id = symbol_db_engine_add_new_files_full_async (priv->sdbe_globals,
 							es_data->special_abort_scan == FALSE ? 
 									es_data->package_name : NULL, 
+	    					"1.0",
 							files_to_scan_array,
 							languages_array,
 							es_data->special_abort_scan == FALSE ? 
@@ -682,17 +694,6 @@ on_pkg_config_exit (AnjutaLauncher * launcher, int child_pid,
 						 g_queue_get_length (priv->engine_queue),
 						 es_data->package_name);
 			g_queue_push_tail (priv->engine_queue, es_data);
-
-/*			
-			gint i;			
-			for (i = 0; i < g_queue_get_length (priv->engine_queue); i++)
-			{
-				EngineScanData *node;
-				node = g_queue_peek_nth (priv->engine_queue, i);
-				DEBUG_PRINT ("DEBUG queue engine [%d]: %s", i, 
-							 node->package_name);
-			}
-*/		
 		}
 		else
 		{
@@ -728,7 +729,7 @@ symbol_db_system_scan_package (SymbolDBSystem *sdbs,
 	priv = sdbs->priv;
 	
 	/* does is already exist on db? */
-	if (symbol_db_system_is_package_parsed (sdbs, package_name) == TRUE)
+	if (symbol_db_system_is_package_parsed (sdbs, package_name, "1.0") == TRUE)
 	{
 		DEBUG_PRINT ("symbol_db_system_scan_package (): no need to scan %s",
 					 package_name);
